# Generated by roxygen2: do not edit by hand

S3method(calc_stats,character)
S3method(calc_stats,default)
S3method(calc_stats,factor)
S3method(calc_stats,logical)
S3method(calc_stats,numeric)
export(AET01_table)
export(AET02_table)
export(as_dtlg_table)
export(calc_counts)
export(calc_desc)
export(calc_stats)
export(cross_tab_to_obsv_tab)
export(dt_copy_semantics)
export(event_count)
export(event_count_by)
export(format_n_pct)
export(indent)
export(label)
export(maybe_copy_dt)
export(merge_table_lists)
export(multi_event_true)
export(nbsp)
export(print_dtlg)
export(round_pct)
export(round_sum)
export(set_dt_copy_semantics)
export(summary_table)
export(summary_table_by)
export(summary_table_by_targets)
export(tern_AET01_table)
export(tern_AET02_table)
export(tern_summary_table)
export(total_events)
export(with_label)
importFrom(data.table,":=")
importFrom(data.table,.N)
importFrom(data.table,.SD)
